@@ -40,8 +40,7 @@ def session_scope(dsn: str):
 
 class Repository(BaseRepository):
     def __init__(self, aggregate: AggregateRoot, dsn: str):
-        super().__init__(aggregate)
-
+        self._aggregate = aggregate
         self._dsn = dsn
 
     def create_connection(self):
@@ -59,13 +58,13 @@ class Repository(BaseRepository):
 
     def find(self, **kwargs) -> AggregateRoot:
         with session_scope(self._dsn) as session:
-            result = session.query(self.__aggregate).filter_by(**kwargs).first()
+            result = session.query(self._aggregate).filter_by(**kwargs).first()
 
         return result
 
     def find_all(self, **kwargs) -> List[AggregateRoot]:
         with session_scope(self._dsn) as session:
-            results = session.query(self.__aggregate).filter_by(**kwargs).all()
+            results = session.query(self._aggregate).filter_by(**kwargs).all()
 
             return results
 
